@@ -133,6 +133,7 @@
 #![warn(clippy::option_option)]
 #![warn(clippy::rc_buffer)]
 #![deny(clippy::ref_option_ref)]
+#![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
@@ -232,7 +233,7 @@ pub mod testing__ {
     }
     impl<T, E> TestOutcome for Result<T, E> {
         fn check_ok(&self) {
-            assert!(self.is_ok())
+            assert!(self.is_ok());
         }
     }
 }
